'use strict';

var _queues = require('../config/queues');

var _wikidotKit = require('../config/wikidot-kit');

var _wikidotKit2 = _interopRequireDefault(_wikidotKit);

var _sentry = require('../config/sentry');

var _sentry2 = _interopRequireDefault(_sentry);

var _pino = require('../config/pino');

var _pino2 = _interopRequireDefault(_pino);

var _importWikidotPage = require('../jobs/import-wikidot-page');

var _importWikidotPage2 = _interopRequireDefault(_importWikidotPage);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_pino2.default.info('Import worker ready');

_queues.importQueue.process(function (job) {
    var params = job.data;

    switch (params.action) {

        case 'full-import':
            _pino2.default.info('Performing full import from ' + params.wiki);
            return _wikidotKit2.default.fetchPagesList({ wiki: params.wiki }).then(function (pages) {
                pages.forEach(function (pageName) {
                    _queues.importQueue.add({
                        action: 'page-import',
                        wiki: params.wiki,
                        name: pageName
                    });
                });
                _pino2.default.info('Full import from ' + params.wiki + ' enqueued');

                _sentry2.default.captureMessage('Full wiki pages import scheduled', {
                    level: 'info',
                    wiki: params.wiki,
                    pagesNumber: pages.length
                });
            }).catch(function (error) {
                _sentry2.default.captureException(error, { data: params });
            });

        case 'page-import':
            return (0, _importWikidotPage2.default)({ wiki: params.wiki, name: params.name });

        default:
            _pino2.default.error('Rejecting job with unknown action "' + params.action + '"');
            return Promise.reject('Unknown job import job type "' + params.type + '"');
    }
});
//# sourceMappingURL=worker.js.map